# SimpleTextarea with _BidiSupport

The value of the textDir setted in all examples, in the text box widget itself.

I'm a LTR SimpleTextarea
Lorem ipsum dolor sit amet, consectetuer adipiscing elit!
I'm a RTL SimpleTextarea
Lorem ipsum dolor sit amet, consectetuer adipiscing elit!
I'm a contextual SimpleTexarea
הטקסט מוצג כמו שצריך ואני קונטקסטואלי!

## Initially empty and programmatically created - Simple Textareas

textDir="ltr":
textDir="rtl":
textDir="auto":